@@ -2,5 +2,5 @@ from __future__ import absolute_import
 from .emvcs import *
 
 __name__ = "emvcs"
-__init__ = ["Get"]
-__version__ = "1.0"
+__init__ = [Get()]
+__version__ = "2.1"
