@@ -2,17 +2,17 @@ import smtplib
 from random import randint
 from email.header import Header
 from email.mime.text import MIMEText
+from time import sleep
  
-def Get(names, title, message):
+def Get(names, title, message, waittime):
     mail_host=names[0]
     mail_user=names[1]  
     mail_pass=names[2] 
     receivers = names[3]
 
-    a = str(message[0] + " ")
-    b = str(randint(100000, 999999))
-    c = str(" " + message[1])
-    message = MIMEText(str(a + b + c), 'plain', 'utf-8')
+    ramd = str(randint(100000, 999999))
+    msg = message %ramd
+    message = MIMEText(str(msg), 'plain', 'utf-8')
 
     message['From'] = Header(mail_user)
     message['To'] =  Header(receivers) 
@@ -23,7 +23,7 @@ def Get(names, title, message):
         smtpObj.connect(mail_host, 25)    
         smtpObj.login(mail_user,mail_pass)
         smtpObj.sendmail(mail_user, receivers, message.as_string())
-        return b
+        return ramd
     except smtplib.SMTPException:
         return False
 
